summaryrefslogtreecommitdiff
path: root/tcwg_kernel-build.sh
diff options
context:
space:
mode:
authorMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2021-04-30 10:24:48 +0000
committerMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2021-04-30 10:26:56 +0000
commitd13978e82994797888c9c9ca631283272a2e97c4 (patch)
treea37dc2e2b1341b1d9255ad15e669c3aab11b9ba7 /tcwg_kernel-build.sh
parent0923cce5f9e953606e7bcf142d40b03c5314a164 (diff)
tcwg_kernel-build.sh: Speed up bisections of qemu regressions
... by using ccache for linux builds. Change-Id: Ifc7be118f3d5a5684f001d577d5f265c5d77e12d
Diffstat (limited to 'tcwg_kernel-build.sh')
-rwxr-xr-xtcwg_kernel-build.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/tcwg_kernel-build.sh b/tcwg_kernel-build.sh
index 033c3365..5a0f13e7 100755
--- a/tcwg_kernel-build.sh
+++ b/tcwg_kernel-build.sh
@@ -132,12 +132,13 @@ build_linux_1 ()
;;
esac
# Use ccache only when bisecting linux (or preparing to).
# Otherwise the compiler is new in every build and we would
# only clobber ccache volume.
local ccache=""
if [ x"${rr[mode]}" != x"jenkins-full" ] && \
- [ x"$(print_single_updated_component)" = x"linux" ]; then
+ [ x"$(print_single_updated_component)" = x"linux" \
+ -o x"$(print_single_updated_component)" = x"qemu" ]; then
ccache="ccache"
fi
cat > "$(pwd)"/bin/${rr[target]}-cc <<EOF
@@ -132,12 +132,13 @@ build_linux_1 ()
;;
esac
- # Use ccache only when bisecting linux (or preparing to).
+ # Use ccache only when bisecting linux or qemu (or preparing to).
# Otherwise the compiler is new in every build and we would
# only clobber ccache volume.